@@ -1642,17 +1642,18 @@ fn workspace_unsatisfiable_member_dependencies_conflicting_dev() -> Result<()> {
     bar.child("src/__init__.py").touch()?;
 
     // Resolving should fail.
-    uv_snapshot!(context.filters(), context.lock().current_dir(&workspace), @r###"
+    uv_snapshot!(context.filters(), context.lock().current_dir(&workspace), @r"
     success: false
     exit_code: 1
     ----- stdout -----
 
     ----- stderr -----
+    warning: The `tool.uv.dev-dependencies` field (used in `packages/bar/pyproject.toml`) is deprecated and will be removed in a future release; use `dependency-groups.dev` instead
     Using CPython 3.12.[X] interpreter at: [PYTHON-3.12]
       × No solution found when resolving dependencies:
       ╰─▶ Because bar:dev depends on anyio==4.2.0 and foo depends on anyio==4.1.0, we can conclude that foo and bar:dev are incompatible.
           And because your workspace requires bar:dev and foo, we can conclude that your workspace's requirements are unsatisfiable.
-    "###
+    "
     );
 
     Ok(())
@@ -1930,3 +1931,163 @@ fn transitive_dep_in_git_workspace_with_root() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn workspace_members_with_leading_dot_slash() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    // Build the main workspace with leading `./` in member paths
+    let workspace = context.temp_dir.child("workspace");
+    workspace.child("pyproject.toml").write_str(indoc! {r#"
+        [tool.uv.workspace]
+        members = ["./packages/foo", "./packages/bar"]
+    "#})?;
+
+    // Create package foo that depends on bar
+    let deps = indoc! {r#"
+        dependencies = ["bar"]
+
+        [tool.uv.sources]
+        bar = { workspace = true }
+    "#};
+    make_project(&workspace.join("packages").join("foo"), "foo", deps)?;
+
+    // Create package bar
+    let deps = indoc! {r"
+        dependencies = []
+    "};
+    make_project(&workspace.join("packages").join("bar"), "bar", deps)?;
+
+    uv_snapshot!(context.filters(), context.lock().current_dir(&workspace), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Using CPython 3.12.[X] interpreter at: [PYTHON-3.12]
+    Resolved 2 packages in [TIME]
+    "###
+    );
+
+    let lock: SourceLock = toml::from_str(&fs_err::read_to_string(workspace.join("uv.lock"))?)?;
+
+    assert_json_snapshot!(lock.sources(), @r###"
+    {
+      "bar": {
+        "editable": "packages/bar"
+      },
+      "foo": {
+        "editable": "packages/foo"
+      }
+    }
+    "###);
+
+    // Test syncing from within foo works correctly
+    uv_snapshot!(context.filters(), context.sync().current_dir(workspace.join("packages/foo")), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Using CPython 3.12.[X] interpreter at: [PYTHON-3.12]
+    Creating virtual environment at: [TEMP_DIR]/workspace/.venv
+    Resolved 2 packages in [TIME]
+    Prepared 2 packages in [TIME]
+    Installed 2 packages in [TIME]
+     + bar==0.1.0 (from file://[TEMP_DIR]/workspace/packages/bar)
+     + foo==0.1.0 (from file://[TEMP_DIR]/workspace/packages/foo)
+    "###
+    );
+
+    Ok(())
+}
+
+#[test]
+fn workspace_members_with_parent_directory() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    // Build a workspace with a member outside its directory using `../`
+    let workspace = context.temp_dir.child("workspace");
+    workspace.child("pyproject.toml").write_str(indoc! {r#"
+        [tool.uv.workspace]
+        members = ["../external-package"]
+    "#})?;
+
+    // Create an external package
+    let deps = indoc! {r"
+        dependencies = []
+    "};
+    make_project(
+        &context.temp_dir.join("external-package"),
+        "external-package",
+        deps,
+    )?;
+
+    uv_snapshot!(context.filters(), context.lock().current_dir(&workspace), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Using CPython 3.12.[X] interpreter at: [PYTHON-3.12]
+    Resolved 1 package in [TIME]
+    "###
+    );
+
+    let lock: SourceLock = toml::from_str(&fs_err::read_to_string(workspace.join("uv.lock"))?)?;
+
+    assert_json_snapshot!(lock.sources(), @r###"
+    {
+      "external-package": {
+        "editable": "../external-package"
+      }
+    }
+    "###);
+
+    Ok(())
+}
+
+#[test]
+fn workspace_members_with_complex_relative_paths() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    // Build a workspace with complex relative path normalization
+    let workspace = context.temp_dir.child("workspace");
+    workspace.child("pyproject.toml").write_str(indoc! {r#"
+        [tool.uv.workspace]
+        members = ["./subdir/../../sibling-package"]
+    "#})?;
+
+    // Create a sibling package
+    let deps = indoc! {r"
+        dependencies = []
+    "};
+    make_project(
+        &context.temp_dir.join("sibling-package"),
+        "sibling-package",
+        deps,
+    )?;
+
+    uv_snapshot!(context.filters(), context.lock().current_dir(&workspace), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Using CPython 3.12.[X] interpreter at: [PYTHON-3.12]
+    Resolved 1 package in [TIME]
+    "###
+    );
+
+    let lock: SourceLock = toml::from_str(&fs_err::read_to_string(workspace.join("uv.lock"))?)?;
+
+    assert_json_snapshot!(lock.sources(), @r###"
+    {
+      "sibling-package": {
+        "editable": "../sibling-package"
+      }
+    }
+    "###);
+
+    Ok(())
+}
